#
# spec file for package python-logreduce
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-logreduce
Version:        0.5.2
Release:        bp155.2.10
Summary:        Log file anomaly extractor
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://logreduce.softwarefactory-project.io/
Source:         https://files.pythonhosted.org/packages/source/l/logreduce/logreduce-%{version}.tar.gz
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-CherryPy
Requires:       python-PyYAML
Requires:       python-SQLAlchemy
Requires:       python-aiohttp
Requires:       python-alembic
Requires:       python-gear
Requires:       python-numpy
Requires:       python-requests
Requires:       python-scikit-learn
Requires:       python-scipy
Requires:       python-voluptuous
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module CherryPy}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module alembic}
BuildRequires:  %{python_module gear}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module routes}
BuildRequires:  %{python_module scikit-learn}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module voluptuous}
# /SECTION
%python_subpackages

%description
Based on success logs, logreduce highlights useful text in failed logs.
The goal is to save time in finding a failure's root cause.

On average, learning run at 2000 lines per second, and
testing run at 1300 lines per seconds.

logreduce uses a *model* to learn successful logs and detect novelties in
failed logs:

* Random words are manually removed using regular expression
* Then lines are converted to a matrix of token occurrences
  (using **HashingVectorizer**),
* An unsupervised learner implements neighbor searches
  (using **NearestNeighbors**).

%prep
%setup -q -n logreduce-%{version}
sed -i -e 's,flake8.*,,' test-requirements.txt

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst
%python3_only %{_bindir}/logreduce
%python3_only %{_bindir}/logreduce-client
%python3_only %{_bindir}/logreduce-server
%python3_only %{_bindir}/logreduce-worker
%python3_only %{_bindir}/logreduce-mqtt
%{python_sitelib}/*

%changelog
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 0.5.2
  * Remove webui build by default from the spec
  * Fix download-logs usage
  * Add command line filters configuration file
  * Add benchmark script
  * Add only\_model option to the MQTT service
  * Remove SCL macros from the spec file
  * Fix exclude-lines regexp joblib dump
  * Report result to zuul using an artifact instead of the log\_url
  * Improve tokenizer for OpenStack logs
  * Add exclude lists to the MQTT service
  * Add mqtt based worker
  * Fix IPv6 tokenization when the last field contains letter
  * Add mqtt client service structure
  * Refactor worker process in the main logreduce module
  * Try to detect binary file
  * Ignore bzip2 extension
  * Ignore pcap file
  * Add exclude-lines argument
  * Move the log link to the additional info in the html output
  * Fix concurrent logreduce-tests job
  * Ignore atop.bin file and tarball
  * Make server installation optional
  * Fix scikit-learn 0.21.3 support
  * Ignore files from supportconfig plugins
  * Ignore files from /proc/net
  * Ignore files with .raw extension
  * Correctly show the gaps between hunks of context
  * Show the gaps between hunks of context like grep does
  * Add some short options for convenience
  * Show default values in help text
  * Reduce deprecation warnings by declaring raw strings
  * Add server configuration instructions
- deleted patches
  - scikit.patch (upstreamed)
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add aptch to fix build with new scikit:
  * scikit.patch
* Mon Mar 18 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.4.0 (bsc#1131198)
  * Bump model version and fix typo
  * Add HashingAnnoy model
  * Add hashing\_nn benchmark in doc string
  * Add HashingApproximateNeighbors model
  * Implement iterator interface for file-like objects
  * Refactor TokenizerTests
  * Provide a bit more info about timings of the training
  * Remove support for bag-of-words\_lshf
  * Don't store duplicate data in model
  * Fix heat\_uuid regexp formatting
  * Relax digits\_re again a bit
  * Vectorizer optimisation: don't do word analysing
  * debug\_lineprocess: Handle more than one input file
  * debug\_lineprocess: Format output slightly nicer and remove duplicates
  * Tighten heat\_uuid regexp
  * Tighten length-based regexp matches properly
  * debug\_lineprocess add some simple word / token statistics
  * Blacklist .xml extension
  * Use for loop instead of handcrafted while construct
  * tests: use free tcp port for gearman server
  * Add --model-type argument to top-level command
  * tokenizer: remove sshd warnings
  * Make debugging scripts callable again
  * Reduce code duplication a bit
  * Micro-optimize the tokenization
  * ci: enable gate jobs
  * Make systemd service file SCL independent
  * Transition webui related files to the log-classify name
  * Match uuid\_re before heat\_re
  * Use SqlAlchemy intrinsics for ordering
  * Fix overly greedy date tokenization
  * Fix tokenization error on removing SSH fingerprints
  * DRY: Remove implementation override that also exists in the base class
  * Fix assertEquals() deprecation warning
  * Use generator for reading files
  * tokenizer regexp speedups
  * cmd: add --json argument to report options
  * Spelling typos
  * logreduce: Fix inconsistency for model\_file in model-run
  * logreduce.spec: Fixes
  * README: Add openSUSE instructions
  * Add py36/py37 to the env list as well
  * Run pep8 against pip installed flake8
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Oct 29 2018 Dirk Mueller <dmueller@suse.com>
- update to 0.3.0:
  * Add support for ara database classification
  * Add webui sub-package to the spec file
  * tokenizer: handle hexa numbers
  * react: fix typo and add build time
  * Add React web interface
  * Add worker service to process user report
  * Add anomaly update method
  * Add model skeleton and report import method
  * Add api skeleton
* Wed Oct 24 2018 Dirk Mueller <dmueller@suse.com>
- update to 0.2.0:
  * Use ara[-\_]\*.\*/ in the default ignore paths list
  * Fix download asyncio loop and logger names
  * Record test command used to train models
  * Add a uuid to model object
  * Remove chunk grouping in the process function
  * Rewrite html output using patternfly
  * Collect ZuulBuild in anomaly report
  * Add --cacheonly argument to skip file download
  * Add ara-.\* to the default ignore list
  * Rewrite ZuulBuilds download module to discover base log\_url
  * common: small fixes for automated process
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Mon Jul  9 2018 dmueller@suse.com
- update to 0.1.3:
  * Update zuul-jobs log-classify role
  * Fix ARA report directory link to ara-report
  * Automatically set the zuul-web url for logs.rdoproject.org
  * Add tripleo-ci job tokenization
  * Update README todo lists
  * Fix typo in ARA Records Ansible
  * Start with a capitalized pypi summary
  * Move flake8 from test-requirements to the linter env
* Tue May 22 2018 dmueller@suse.com
- Initial package (0.1.2)
